conv

package
v1.5.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 12, 2026 License: BSD-3-Clause Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Trans8859_1ToUTF8

func Trans8859_1ToUTF8(raw []byte) []byte

func TransUTF8To8859_1

func TransUTF8To8859_1(raw []byte) []byte

func UnsafeBytesToString

func UnsafeBytesToString(b []byte) string

UnsafeBytesToString returns the byte slice as a volatile string THIS IS EVIL CODE. YOU HAVE BEEN WARNED.

func UnsafeStringToBytes

func UnsafeStringToBytes(s string) (b []byte)

UnsafeStringToBytes returns the string as a byte slice THIS IS EVIL CODE. YOU HAVE BEEN WARNED.

Types

This section is empty.

Jump to