Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Trans8859_1ToUTF8 ¶
func TransUTF8To8859_1 ¶
func UnsafeBytesToString ¶
UnsafeBytesToString returns the byte slice as a volatile string THIS IS EVIL CODE. YOU HAVE BEEN WARNED.
func UnsafeStringToBytes ¶
UnsafeStringToBytes returns the string as a byte slice THIS IS EVIL CODE. YOU HAVE BEEN WARNED.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.